# Dash Charlotte

A package of themes, tools and components that I use on my Plotly-Dash web dashboards.

This is still a super early work in progress and probably not very interesting, so don't waste your time here.

## Submodules

- [**Components**](https://github.com/GusFurtado/dash-charlotte/tree/main/dash_charlotte/components)

A set of standard Dash components for a fast and modular dashboard building.

- [**Themes**](https://github.com/GusFurtado/dash-charlotte/tree/main/dash_charlotte/themes)

Tools for easy and consistent styling. Colors, fonts, icon packages and CSS stuff.

- [**Layouts**](https://github.com/GusFurtado/dash-charlotte/tree/main/dash_charlotte/layouts)

Some pre-built page layouts.

## Instatlation

- `pip install dash-charlotte`

## License

- [**MIT**]([LICENSE])

## Getting Started

Check the [example app](https://github.com/GusFurtado/dash-charlotte-live-demo) or the [live demo](https://dash-charlotte.herokuapp.com/).
